@@ -70,7 +70,7 @@ class MetaMainHasInfoRule(AnsibleLintRule):
 
         # since Ansible 2.10 we can add a meta/requirements.yml but
         # we only want to match on meta/main.yml
-        if not str(file.path).endswith('/main.yml'):
+        if file.path.name != 'main.yml':
             return []
 
         galaxy_info = data.get('galaxy_info', False)
